Workspace path canonicalization + machine-local registry.
Re-exports
pub use crate::core::paths::canonical;pub use crate::core::paths::kaizen_dir;pub use crate::core::paths::project_data_dir;
Functions
- db_path
- machine_
workspaces - resolve
- resolve_
project_ name - Resolve a short project name to its registered workspace path.
- resolve_
read - Resolve an existing workspace without creating registry or project state.