pub fn from_config(
q: &TelemetryQueryConfig,
) -> Option<Arc<dyn TelemetryQueryProvider>>Expand description
Build a TelemetryQueryProvider for the configured query authority, or None when pull is off.
pub fn from_config(
q: &TelemetryQueryConfig,
) -> Option<Arc<dyn TelemetryQueryProvider>>Build a TelemetryQueryProvider for the configured query authority, or None when pull is off.