Context passed when appending events so the store can enqueue the sync outbox.
Structs
- Sync
Ingest Context - Everything needed to optionally enqueue a redacted row after a successful insert.
Context passed when appending events so the store can enqueue the sync outbox.