pub fn ingest_ctx(
cfg: &Config,
workspace_root: PathBuf,
) -> Option<SyncIngestContext>Expand description
When sync endpoint is configured, pass this into append_event_with_sync.
pub fn ingest_ctx(
cfg: &Config,
workspace_root: PathBuf,
) -> Option<SyncIngestContext>When sync endpoint is configured, pass this into append_event_with_sync.