pub struct IdentityAllowlist {
pub team: bool,
pub workspace_label: bool,
pub runner_label: bool,
pub actor_kind: bool,
pub actor_label: bool,
pub agent: bool,
pub model: bool,
pub env: bool,
pub job: bool,
pub branch: bool,
}Expand description
Per-field allowlist: when false (default), the field is omitted or hashed in telemetry exports.
Fields
team: boolworkspace_label: boolrunner_label: boolactor_kind: boolactor_label: boolagent: boolmodel: boolenv: booljob: boolbranch: boolTrait Implementations
Sourceimpl Clone for IdentityAllowlist
impl Clone for IdentityAllowlist
Sourcefn clone(&self) -> IdentityAllowlist
fn clone(&self) -> IdentityAllowlist
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IdentityAllowlist
impl Debug for IdentityAllowlist
Sourceimpl Default for IdentityAllowlist
impl Default for IdentityAllowlist
Sourcefn default() -> IdentityAllowlist
fn default() -> IdentityAllowlist
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for IdentityAllowlist
impl<'de> Deserialize<'de> for IdentityAllowlist
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for IdentityAllowlist
impl PartialEq for IdentityAllowlist
Sourcefn eq(&self, other: &IdentityAllowlist) -> bool
fn eq(&self, other: &IdentityAllowlist) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for IdentityAllowlist
impl Serialize for IdentityAllowlist
impl Eq for IdentityAllowlist
impl StructuralPartialEq for IdentityAllowlist