Machine-local SQLite registry ($KAIZEN_HOME/machine.db) — known workspace roots, init history.
Functions
- db_path
- Path to the machine registry db, or
NoneifKAIZEN_HOME/HOMEis unset. - is_
registered trueif this path is a row in the machine registry (compared after canonicalize).- list_
paths - All known workspace paths from the machine registry.
- list_
paths_ including_ missing - All registry rows, including workspace paths that no longer exist.
- record_
init - Record a successful
kaizen init(incrementsinit_count, optional git + version). - status
- Read machine registry status without creating machine state.
- upsert_
from_ resolve - Upsert a workspace seen from
resolve.