Module context

Module context 

Context passed when appending events so the store can enqueue the sync outbox.

Structs

SyncIngestContext
Everything needed to optionally enqueue a redacted row after a successful insert.